==> provider_software_3.5.1.tar.gz: provider_software_3.5.1/lib/biocase/tools/update.py <==
# -*- coding: utf-8 -*-

'''Simple functions for updating a BioCASe installation.
'''

import urllib, os, logging
from datetime import datetime
from biocase import __version__
import biocase.configuration
cfg = biocase.configuration.Cfg()
log = logging.getLogger("biocase.tools")

SUBVERSION_FILEPATH = 'http://ww2.biocase.org/svn/bps2/branches/stable/README.TXT'
CACHE_FILE = os.path.join(cfg.cacheLocator, 'latest_version')


# Returns a hint indicating the update status of the current BioCASe installation
def update_hint():

    try:
        # Search for updates only once every week
        search_for_updates = True
        if os.path.exists(CACHE_FILE):
            modified = datetime.fromtimestamp(os.stat(CACHE_FILE).st_mtime)
            elapsed = datetime.now() - modified
            if elapsed.days < 7:
                search_for_updates = False

        if search_for_updates:
            # Get latest stable version from Subversion
            f = urllib.urlopen(SUBVERSION_FILEPATH)
            version_string = None
            for line in f.readlines():
                if line.startswith('Version'):
                    version_string = line[7:].strip().strip(':').strip()
                    break
            f.close()

            if version_string:
                # Store the available version in  cache file
                f = open(CACHE_FILE, 'w')
                f.write(version_string)
                f.close()
            else:
                raise Exception("Couldn't get current BioCASe version from repository file %s" % SUBVERSION_FILEPATH)

        else:
            # Get latest version from cache file
            f = open(CACHE_FILE)
            version_string = f.read()
            f.close()

        # Compare versions
        try:
            if __version__ != version_string.split()[0]:
                return '<span class="badstatus">A new version of BioCASe is available: %s. Please <a href="http://www.biocase.org/products/provider_software" target="_blank">download</a> and install the latest version.</span>' % version_string
            else:
                return '<span class="goodstatus">Your BioCASe installation is up to date.</span>'
        except:
            raise Exception("Version string '%s' couldn't be parsed" % version_string)

    except Exception, ex:
        # On exception, return nothing
        log.error("Check for updates failed: %s." % ex)

==> provider_software_3.7.4.tar.gz: provider_software_3.7.4/lib/biocase/tools/update.py <==
# -*- coding: utf-8 -*-

'''Simple functions for updating a BioCASe installation.
'''

import urllib, os, logging
from datetime import datetime
from biocase import __version__
import biocase.configuration
cfg = biocase.configuration.Cfg()
log = logging.getLogger("biocase.tools")

SUBVERSION_FILEPATH = 'http://ww2.biocase.org/svn/bps2/branches/stable/README.TXT'
CACHE_FILE = os.path.join(cfg.cacheLocator, 'latest_version')


# Returns a hint indicating the update status of the current BioCASe installation
def update_hint():

    try:
        # Search for updates only once every week
        search_for_updates = True
        if os.path.exists(CACHE_FILE):
            modified = datetime.fromtimestamp(os.stat(CACHE_FILE).st_mtime)
            elapsed = datetime.now() - modified
            if elapsed.days < 7:
                search_for_updates = False

        if search_for_updates:
            # Get latest stable version from Subversion
            f = urllib.urlopen(SUBVERSION_FILEPATH)
            version_string = None
            for line in f.readlines():
                if line.startswith('Version'):
                    version_string = line[7:].strip().strip(':').strip()
                    break
            f.close()

            if version_string:
                # Store the available version in  cache file
                f = open(CACHE_FILE, 'w')
                f.write(version_string)
                f.close()
            else:
                raise Exception("Couldn't get current BioCASe version from repository file %s" % SUBVERSION_FILEPATH)

        else:
            # Get latest version from cache file
            f = open(CACHE_FILE)
            version_string = f.read()
            f.close()

        # Compare versions
        try:
            if __version__ < version_string.split()[0]:
                return '<span class="badstatus">A new version of BioCASe is available: %s. Please <a href="http://www.biocase.org/products/provider_software" target="_blank">download</a> and install the latest version.</span>' % version_string
            else:
                return '<span class="goodstatus">Your BioCASe installation is up to date.</span>'
        except:
            raise Exception("Version string '%s' couldn't be parsed" % version_string)

    except Exception, ex:
        # On exception, return nothing
        log.error("Check for updates failed: %s." % ex)
